@@ -23,9 +23,9 @@ end_to_end = Workflow(
     workflow_package=__package__,
 )
 end_to_end.add_node(task=TransferL0Data, upstreams=None)
-end_to_end.add_node(task=QualityL0Metrics, upstreams=TransferL0Data)
-end_to_end.add_node(task=ParseL0TestInputData, upstreams=QualityL0Metrics)
-end_to_end.add_node(task=GenerateCalibratedData, upstreams=ParseL0TestInputData)
+end_to_end.add_node(task=ParseL0TestInputData, upstreams=TransferL0Data)
+end_to_end.add_node(task=QualityL0Metrics, upstreams=ParseL0TestInputData)
+end_to_end.add_node(task=GenerateCalibratedData, upstreams=QualityL0Metrics)
 end_to_end.add_node(task=WriteL1Data, upstreams=GenerateCalibratedData)
 end_to_end.add_node(task=QualityL1Metrics, upstreams=WriteL1Data)
 end_to_end.add_node(task=SubmitQuality, upstreams=QualityL1Metrics)
